@@ -1,16 +1,12 @@
 #ifndef CPPUNITTEST_EXTENSIONSSUITE_H
 #define CPPUNITTEST_EXTENSIONSSUITE_H
 
+#include <cppunit/Portability.h>
 #include <string>
 
-namespace CppUnitTest
+inline std::string extensionSuiteName()
 {
-
-  inline std::string extensionSuiteName()
-  {
-    return "Extensions";
-  }
-
+  return "Extensions";
 }
 
-#endif // CPPUNITTEST_EXTENSIONSSUITE_H
\ No newline at end of file
+#endif // CPPUNITTEST_EXTENSIONSSUITE_H
